# oneNeuron_pypi
## create direcotry inside directory
```bash
mkdirs src/oneNeuron
```
## create direcotry inside directory the directory create another directory
```bash
mkdirs -p src/oneNeuron
```
### create file inside directory 
```bash
touch src/oneNeuron/perceptron.py
```